@@ -1,9 +1,9 @@
 package Hailo::Role::Tokenizer;
-use 5.10.0;
+use 5.010;
 use MooseX::Role::Strict;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 requires 'find_key_tokens';
 requires 'make_tokens';
