@@ -1,9 +1,9 @@
 package Hailo::Role::UI;
-use 5.10.0;
+use 5.010;
 use MooseX::Role::Strict;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 requires 'run';
 
