@@ -1,10 +1,10 @@
 package Hailo::Storage::DBD::mysql;
-use 5.10.0;
+use 5.010;
 use Moose;
 use MooseX::StrictConstructor;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 extends 'Hailo::Storage::Mixin::DBD';
 
