@@ -1,5 +1,5 @@
 package Hailo::Storage::Mixin::CHI;
-use 5.10.0;
+use 5.010;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw<HashRef>;
@@ -7,7 +7,7 @@ use CHI;
 use Digest::MD4 qw(md4_hex);
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 extends qw(Hailo::Storage::Mixin::Hash::Flat);
 
