@@ -1,12 +1,12 @@
 package Hailo::Storage::Perl;
-use 5.10.0;
+use 5.010;
 use Moose;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw<HashRef Int Str>;
 use Storable;
 use namespace::clean -except => 'meta';
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 extends qw(Hailo::Storage::Mixin::Hash
            Hailo::Storage::Mixin::Storable);
